# Table of Contents

- [relation-mapping-from-sap-leanix-to-collibra](<./relation-mapping-from-sap-leanix-to-collibra.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Relation Mapping from SAP LeanIX to Collibra](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra.md>)
  - [Introduction](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra/Introduction.md>)
  - [Configuring Mapping of Relations](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra/Configuring-Mapping-of-Relations.md>)
  - [Simple Relation Strategy](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra/Simple-Relation-Strategy.md>)
  - [Complex Relation Strategy](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra/Complex-Relation-Strategy.md>)
  - [Intermediate Asset Strategy](<./Relation-Mapping-from-SAP-LeanIX-to-Collibra/Intermediate-Asset-Strategy.md>)
